@@ -57,34 +57,6 @@ class CfnCustomResource(
 
         jsii.create(CfnCustomResource, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnCustomResource":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -215,34 +187,6 @@ class CfnMacro(
 
         jsii.create(CfnMacro, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnMacro":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -466,9 +410,7 @@ class CfnStack(
         *,
         template_url: str,
         notification_arns: typing.Optional[typing.List[str]] = None,
-        parameters: typing.Optional[
-            typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]
-        ] = None,
+        parameters: typing.Optional[typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]] = None,
         tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
         timeout_in_minutes: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -492,34 +434,6 @@ class CfnStack(
 
         jsii.create(CfnStack, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnStack":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -593,9 +507,7 @@ class CfnStack(
     @jsii.member(jsii_name="parameters")
     def parameters(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]]:
         """``AWS::CloudFormation::Stack.Parameters``.
 
         see
@@ -606,9 +518,7 @@ class CfnStack(
     @parameters.setter
     def parameters(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]],
     ) -> None:
         jsii.set(self, "parameters", value)
 
@@ -644,9 +554,7 @@ class CfnStackProps:
         *,
         template_url: str,
         notification_arns: typing.Optional[typing.List[str]] = None,
-        parameters: typing.Optional[
-            typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]
-        ] = None,
+        parameters: typing.Optional[typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]] = None,
         tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
         timeout_in_minutes: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -694,9 +602,7 @@ class CfnStackProps:
     @builtins.property
     def parameters(
         self,
-    ) -> typing.Optional[
-        typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]
-    ]:
+    ) -> typing.Optional[typing.Union[typing.Mapping[str, str], aws_cdk.core.IResolvable]]:
         """``AWS::CloudFormation::Stack.Parameters``.
 
         see
@@ -769,34 +675,6 @@ class CfnWaitCondition(
 
         jsii.create(CfnWaitCondition, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnWaitCondition":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -902,34 +780,6 @@ class CfnWaitConditionHandle(
         """
         jsii.create(CfnWaitConditionHandle, self, [scope, id])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: aws_cdk.core.Construct,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: aws_cdk.core.ICfnFinder,
-    ) -> "CfnWaitConditionHandle":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
